# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from data_repo_client.paths.api_repository_v1_journal_resource_key import Api

from data_repo_client.paths import PathValues

path = PathValues.API_REPOSITORY_V1_JOURNAL_RESOURCE_KEY