from data_repo_client.paths.api_repository_v1_datasets_id_policies_policy_name_members_member_email.delete import ApiFordelete


class ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembersMemberEmail(
    ApiFordelete,
):
    pass
