from data_repo_client.paths.ga4gh_drs_v1_objects_object_id.get import ApiForget
from data_repo_client.paths.ga4gh_drs_v1_objects_object_id.post import ApiForpost
from data_repo_client.paths.ga4gh_drs_v1_objects_object_id.options import ApiForoptions


class Ga4ghDrsV1ObjectsObjectId(
    ApiForget,
    ApiForpost,
    ApiForoptions,
):
    pass
