from data_repo_client.paths.api_resources_v1_profiles_id_policies_policy_name_members_member_email.delete import ApiFordelete


class ApiResourcesV1ProfilesIdPoliciesPolicyNameMembersMemberEmail(
    ApiFordelete,
):
    pass
