from data_repo_client.paths.api_repository_v1_datasets.get import ApiForget
from data_repo_client.paths.api_repository_v1_datasets.post import ApiForpost


class ApiRepositoryV1Datasets(
    ApiForget,
    ApiForpost,
):
    pass
