from data_repo_client.paths.api_repository_v1_snapshots_id_policies_policy_name_members.post import ApiForpost


class ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembers(
    ApiForpost,
):
    pass
