from data_repo_client.paths.ga4gh_drs_v1_objects_object_id_access_access_id.get import ApiForget
from data_repo_client.paths.ga4gh_drs_v1_objects_object_id_access_access_id.post import ApiForpost


class Ga4ghDrsV1ObjectsObjectIdAccessAccessId(
    ApiForget,
    ApiForpost,
):
    pass
