from data_repo_client.paths.api_repository_v1_datasets_id_files_fileid.get import ApiForget
from data_repo_client.paths.api_repository_v1_datasets_id_files_fileid.delete import ApiFordelete


class ApiRepositoryV1DatasetsIdFilesFileid(
    ApiForget,
    ApiFordelete,
):
    pass
