# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from data_repo_client.paths.ga4gh_drs_v1_objects_object_id_access_access_id import Api

from data_repo_client.paths import PathValues

path = PathValues.GA4GH_DRS_V1_OBJECTS_OBJECT_ID_ACCESS_ACCESS_ID