from data_repo_client.paths.api_repository_v1_configs_name.get import ApiForget
from data_repo_client.paths.api_repository_v1_configs_name.put import ApiForput


class ApiRepositoryV1ConfigsName(
    ApiForget,
    ApiForput,
):
    pass
