from data_repo_client.paths.api_resources_v1_profiles_id.get import ApiForget
from data_repo_client.paths.api_resources_v1_profiles_id.delete import ApiFordelete


class ApiResourcesV1ProfilesId(
    ApiForget,
    ApiFordelete,
):
    pass
